==> jupyterlite-xeus-lua-0.3.0.tar.gz: jupyterlite-xeus-lua-0.3.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/v0.2.0...57b43c598768a3c2e5edf4cd5cb35a56c677ed8c))

### Enhancements made

- No JS callback [#34](https://github.com/jupyterlite/xeus-lua-kernel/pull/34) ([@SylvainCorlay](https://github.com/SylvainCorlay))

### Other merged PRs

- updated to 0.6.3 / fixes xwidgets layout error [#35](https://github.com/jupyterlite/xeus-lua-kernel/pull/35) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-11-18&to=2022-03-17&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-11-18..2022-03-17&type=Issues) | [@SylvainCorlay](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ASylvainCorlay+updated%3A2021-11-18..2022-03-17&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/v0.1.1...af5f8dae02a71dce1f0664b081bfba8366106c0c))

### Enhancements made

- Binary buffers [#30](https://github.com/jupyterlite/xeus-lua-kernel/pull/30) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-10-22&to=2021-11-16&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-10-22..2021-11-16&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/first-commit...47d189ec2368f191401605bdbb1217353cbd635f))

### Enhancements made

- using kernel agnostic names [#23](https://github.com/jupyterlite/xeus-lua-kernel/pull/23) ([@DerThorsten](https://github.com/DerThorsten))
- Fix handling of kernelspec logos [#20](https://github.com/jupyterlite/xeus-lua-kernel/pull/20) ([@jtpio](https://github.com/jtpio))
- Size [#17](https://github.com/jupyterlite/xeus-lua-kernel/pull/17) ([@DerThorsten](https://github.com/DerThorsten))
- No more shared-array-buffer [#14](https://github.com/jupyterlite/xeus-lua-kernel/pull/14) ([@DerThorsten](https://github.com/DerThorsten))

### Bugs fixed

- Fix Check Release job on CI [#12](https://github.com/jupyterlite/xeus-lua-kernel/pull/12) ([@jtpio](https://github.com/jtpio))
- copy wasm file via plugin [#10](https://github.com/jupyterlite/xeus-lua-kernel/pull/10) ([@DerThorsten](https://github.com/DerThorsten))

### Maintenance and upkeep improvements

- Update package name and cleanup [#26](https://github.com/jupyterlite/xeus-lua-kernel/pull/26) ([@jtpio](https://github.com/jtpio))
- Update links after the move to the org [#25](https://github.com/jupyterlite/xeus-lua-kernel/pull/25) ([@jtpio](https://github.com/jtpio))
- pinning the repos in the Dockerfile [#22](https://github.com/jupyterlite/xeus-lua-kernel/pull/22) ([@DerThorsten](https://github.com/DerThorsten))
- More cleanup [#21](https://github.com/jupyterlite/xeus-lua-kernel/pull/21) ([@jtpio](https://github.com/jtpio))
- Cleanup webpack.config.js [#19](https://github.com/jupyterlite/xeus-lua-kernel/pull/19) ([@jtpio](https://github.com/jtpio))
- Upload the releaser distributions as artifacts [#18](https://github.com/jupyterlite/xeus-lua-kernel/pull/18) ([@jtpio](https://github.com/jtpio))
- minor fixes [#15](https://github.com/jupyterlite/xeus-lua-kernel/pull/15) ([@DerThorsten](https://github.com/DerThorsten))
- Remove unused files [#13](https://github.com/jupyterlite/xeus-lua-kernel/pull/13) ([@jtpio](https://github.com/jtpio))
- Build the extension [#6](https://github.com/jupyterlite/xeus-lua-kernel/pull/6) ([@jtpio](https://github.com/jtpio))
- Troubleshoot build issues [#3](https://github.com/jupyterlite/xeus-lua-kernel/pull/3) ([@jtpio](https://github.com/jtpio))
- added webpack config [#2](https://github.com/jupyterlite/xeus-lua-kernel/pull/2) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-10-04&to=2021-10-22&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-10-04..2021-10-22&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3Ajtpio+updated%3A2021-10-04..2021-10-22&type=Issues)

==> jupyterlite-xeus-lua-0.3.1.tar.gz: jupyterlite-xeus-lua-0.3.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.1

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/v0.3.0...c3e9eb7a7eca22e95640db22534751905c79002b))

### Merged PRs

- Update xcanvas [#37](https://github.com/jupyterlite/xeus-lua-kernel/pull/37) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2022-03-18&to=2022-04-12&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3AmartinRenou+updated%3A2022-03-18..2022-04-12&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/v0.2.0...57b43c598768a3c2e5edf4cd5cb35a56c677ed8c))

### Enhancements made

- No JS callback [#34](https://github.com/jupyterlite/xeus-lua-kernel/pull/34) ([@SylvainCorlay](https://github.com/SylvainCorlay))

### Other merged PRs

- updated to 0.6.3 / fixes xwidgets layout error [#35](https://github.com/jupyterlite/xeus-lua-kernel/pull/35) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-11-18&to=2022-03-17&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-11-18..2022-03-17&type=Issues) | [@SylvainCorlay](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ASylvainCorlay+updated%3A2021-11-18..2022-03-17&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/v0.1.1...af5f8dae02a71dce1f0664b081bfba8366106c0c))

### Enhancements made

- Binary buffers [#30](https://github.com/jupyterlite/xeus-lua-kernel/pull/30) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-10-22&to=2021-11-16&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-10-22..2021-11-16&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-lua-kernel/compare/first-commit...47d189ec2368f191401605bdbb1217353cbd635f))

### Enhancements made

- using kernel agnostic names [#23](https://github.com/jupyterlite/xeus-lua-kernel/pull/23) ([@DerThorsten](https://github.com/DerThorsten))
- Fix handling of kernelspec logos [#20](https://github.com/jupyterlite/xeus-lua-kernel/pull/20) ([@jtpio](https://github.com/jtpio))
- Size [#17](https://github.com/jupyterlite/xeus-lua-kernel/pull/17) ([@DerThorsten](https://github.com/DerThorsten))
- No more shared-array-buffer [#14](https://github.com/jupyterlite/xeus-lua-kernel/pull/14) ([@DerThorsten](https://github.com/DerThorsten))

### Bugs fixed

- Fix Check Release job on CI [#12](https://github.com/jupyterlite/xeus-lua-kernel/pull/12) ([@jtpio](https://github.com/jtpio))
- copy wasm file via plugin [#10](https://github.com/jupyterlite/xeus-lua-kernel/pull/10) ([@DerThorsten](https://github.com/DerThorsten))

### Maintenance and upkeep improvements

- Update package name and cleanup [#26](https://github.com/jupyterlite/xeus-lua-kernel/pull/26) ([@jtpio](https://github.com/jtpio))
- Update links after the move to the org [#25](https://github.com/jupyterlite/xeus-lua-kernel/pull/25) ([@jtpio](https://github.com/jtpio))
- pinning the repos in the Dockerfile [#22](https://github.com/jupyterlite/xeus-lua-kernel/pull/22) ([@DerThorsten](https://github.com/DerThorsten))
- More cleanup [#21](https://github.com/jupyterlite/xeus-lua-kernel/pull/21) ([@jtpio](https://github.com/jtpio))
- Cleanup webpack.config.js [#19](https://github.com/jupyterlite/xeus-lua-kernel/pull/19) ([@jtpio](https://github.com/jtpio))
- Upload the releaser distributions as artifacts [#18](https://github.com/jupyterlite/xeus-lua-kernel/pull/18) ([@jtpio](https://github.com/jtpio))
- minor fixes [#15](https://github.com/jupyterlite/xeus-lua-kernel/pull/15) ([@DerThorsten](https://github.com/DerThorsten))
- Remove unused files [#13](https://github.com/jupyterlite/xeus-lua-kernel/pull/13) ([@jtpio](https://github.com/jtpio))
- Build the extension [#6](https://github.com/jupyterlite/xeus-lua-kernel/pull/6) ([@jtpio](https://github.com/jtpio))
- Troubleshoot build issues [#3](https://github.com/jupyterlite/xeus-lua-kernel/pull/3) ([@jtpio](https://github.com/jtpio))
- added webpack config [#2](https://github.com/jupyterlite/xeus-lua-kernel/pull/2) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-lua-kernel/graphs/contributors?from=2021-10-04&to=2021-10-22&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3ADerThorsten+updated%3A2021-10-04..2021-10-22&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-lua-kernel+involves%3Ajtpio+updated%3A2021-10-04..2021-10-22&type=Issues)
